@@ -1269,6 +1269,8 @@ void Smb4KScanner::processShares()
       {
         // Do nothing
       }
+      
+      return;
     }
     else if ( stderr_output.contains( "could not obtain sid for domain", Qt::CaseSensitive ) )
     {
@@ -1279,17 +1281,26 @@ void Smb4KScanner::processShares()
       m_queue.enqueue( QueueContainer( Shares, m_priv->host() ) );
 
       m_priv->retry = true;
+      
+      return;
     }
     else
     {
-      // We could not get the list of shares:
-      emit failed();
+      if ( !stderr_output.contains( "creating lame", Qt::CaseSensitive ) )
+      {
+	// We could not get the list of shares:
+	emit failed();
 
-      // Notify the user:
-      Smb4KCoreMessage::error( ERROR_GETTING_SHARES, QString(), stderr_output );
+	// Notify the user:
+	Smb4KCoreMessage::error( ERROR_GETTING_SHARES, QString(), stderr_output );
+	
+	return;
+      }
+      else
+      {
+	// Do nothing
+      }
     }
-
-    return;
   }
 
   // There was no error. We can proceed with processing the
@@ -1320,13 +1331,24 @@ void Smb4KScanner::processShares()
     }
     else
     {
-      if ( list.at( i ).contains( " Disk     ", Qt::CaseSensitive ) )
+      if ( list.at( i ).contains( " Disk     ", Qt::CaseSensitive ) ||
+	   (!list.at( i ).contains( " Disk     ", Qt::CaseSensitive ) &&
+            list.at( i ).trimmed().endsWith( " Disk", Qt::CaseSensitive )) )
       {
-        temp_share.setName( list.at( i ).section( " Disk     ", 0, 0 ).trimmed() );
+	if ( !list.at( i ).trimmed().endsWith( " Disk", Qt::CaseSensitive ) )
+	{
+	  temp_share.setName( list.at( i ).section( " Disk     ", 0, 0 ).trimmed() );
+	  temp_share.setComment( list.at( i ).section( " Disk     ", 1, 1 ).trimmed() );
+	}
+	else
+	{
+	  temp_share.setName( list.at( i ).section( " Disk", 0, 0 ).trimmed() );
+	  temp_share.setComment( "" );
+	}
+	
         temp_share.setHost( m_priv->host().name() );
         temp_share.setWorkgroup( m_priv->host().workgroup() );
         temp_share.setType( "Disk" );
-        temp_share.setComment( list.at( i ).section( " Disk     ", 1, 1 ).trimmed() );
 
         // Check if we also have an IP address we can add to the
         // share object.
@@ -1364,13 +1386,24 @@ void Smb4KScanner::processShares()
 
         continue;
       }
-      else if ( list.at( i ).contains( " IPC      ", Qt::CaseSensitive ) )
+      else if ( list.at( i ).contains( " IPC      ", Qt::CaseSensitive ) ||
+		(!list.at( i ).contains( " IPC      ", Qt::CaseSensitive ) &&
+                 list.at( i ).trimmed().endsWith( " IPC", Qt::CaseSensitive )) )
       {
-        temp_share.setName( list.at( i ).section( " IPC      ", 0, 0 ).trimmed() );
+	if ( !list.at( i ).trimmed().endsWith( " IPC", Qt::CaseSensitive ) )
+	{
+	  temp_share.setName( list.at( i ).section( " IPC      ", 0, 0 ).trimmed() );
+	  temp_share.setComment( list.at( i ).section( " IPC      ", 1, 1 ).trimmed() );
+	}
+	else
+	{
+	  temp_share.setName( list.at( i ).section( " IPC", 0, 0 ).trimmed() );
+	  temp_share.setComment( "" );
+	}
+	
         temp_share.setHost( m_priv->host().name() );
         temp_share.setWorkgroup( m_priv->host().workgroup() );
         temp_share.setType( "IPC" );
-        temp_share.setComment( list.at( i ).section( " IPC      ", 1, 1 ).trimmed() );
 
         // Check if we also have an IP address we can add to the
         // share object.
@@ -1398,13 +1431,24 @@ void Smb4KScanner::processShares()
 
         continue;
       }
-      else if ( list.at( i ).contains( " Print    ", Qt::CaseSensitive ) )
+      else if ( list.at( i ).contains( " Print    ", Qt::CaseSensitive ) ||
+	        (!list.at( i ).contains( " Print    ", Qt::CaseSensitive ) &&
+                 list.at( i ).trimmed().endsWith( " Print", Qt::CaseSensitive )) )
       {
-        temp_share.setName( list.at( i ).section( " Print    ", 0, 0 ).trimmed() );
+	if ( !list.at( i ).trimmed().endsWith( " Print", Qt::CaseSensitive ) )
+	{
+	  temp_share.setName( list.at( i ).section( " Print    ", 0, 0 ).trimmed() );
+	  temp_share.setComment( list.at( i ).section( " Print    ", 1, 1 ).trimmed() );
+	}
+	else
+	{
+	  temp_share.setName( list.at( i ).section( " Print", 0, 0 ).trimmed() );
+	  temp_share.setComment( "" );
+	}
+	
         temp_share.setHost( m_priv->host().name() );
         temp_share.setWorkgroup( m_priv->host().workgroup() );
         temp_share.setType( "Printer" );
-        temp_share.setComment( list.at( i ).section( " Print    ", 1, 1 ).trimmed() );
 
         // Check if we also have an IP address we can add to the
         // share object.
