@@ -27,12 +27,9 @@
 #include <config.h>
 #endif
 
-#if !defined(__FreeBSD__) && !defined(__solaris__) && !defined(USE_SOLARIS)
+#ifndef __FreeBSD__
 #include <sys/statfs.h>
-#elif defined(__solaris__) || defined(USE_SOLARIS)
-#include <sys/types.h>
-#include <sys/statvfs.h>
-#elif defined(__FreeBSD__)
+#else
 #include <sys/param.h>
 #include <sys/mount.h>
 #endif
@@ -50,13 +47,13 @@
 #include <iostream>
 using namespace std;
 
-#define SMB4K_UMOUNT_VERSION "0.14"
+#define SMB4K_UMOUNT_VERSION "0.15"
 
 
 void info()
 {
 	cout << "This is smb4k_umount (version " << SMB4K_UMOUNT_VERSION << "), the unmount utility of Smb4K" << endl;
-	cout << "Copyright (C) 2004-2007, Alexander Reinholdt" << endl;
+	cout << "Copyright (C) 2004-2008, Alexander Reinholdt" << endl;
 	cout << endl;
 	cout << "Usage:" << endl;
 #ifndef __FreeBSD__
@@ -84,11 +81,11 @@ void info()
 #ifdef __linux__
 	cout << "    -l\t\tPerform a lazy unmount. See the manual page of umount for" << endl;
 	cout << "\t\tmore information. Please note, that this argument is only" << endl;
-	cout << "\t\trecognized in super user mode, i.e. if '--suid' is supplied," << endl;
-	cout << "\t\tand that you need kernel version 2.4.11 or later." << endl;
+	cout << "\t\trecognized in super user mode, i.e. if '-s' or '--suid' is" << endl;
+	cout << "\t\t supplied, and that you need kernel version 2.4.11 or later." << endl;
 #endif
 	cout << endl;
-	cout << "  {mountpoint}\tThe path where the share is mounted to." << endl;
+	cout << "  {mountpoint}\tThe path where the share is mounted." << endl;
 	cout << endl;
 	cout << "  --help\tDisplay this help screen and exit." << endl;
 	cout << "  --version\tDisplay the version information and exit." << endl;
@@ -138,19 +135,9 @@ bool check_filesystem( const char *path, const char *fs )
 {
 	bool ok = false;
 
-#if !defined(__solaris__) && !defined(USE_SOLARIS)
 	struct statfs filesystem;
-#else
-	struct statvfs filesystem;
-#endif
 
-#if !defined(__solaris__) && !defined(USE_SOLARIS) && !defined(__irix__)
 	if ( statfs( path, &filesystem ) == -1 )
-#elif defined(__irix__)
-	if ( statfs( path, &filesystem, sizeof( filesystem ), 0 ) == -1 )
-#else
-	if ( statvfs( path, &filesystem ) == -1 )
-#endif
 	{
 		int err_code = errno;
 
@@ -168,7 +155,7 @@ bool check_filesystem( const char *path, const char *fs )
 		return ok;
 	}
 
-#if !defined(__FreeBSD__) && !defined(__solaris__) && !defined(USE_SOLARIS)
+#ifndef __FreeBSD__
 	// First entry is for CIFS, the second for SMBFS.
 	if ( (uint)filesystem.f_type == 0xFF534D42 && !strncmp( fs, "cifs", strlen( fs )+1 ) )
 	{
@@ -178,29 +165,11 @@ bool check_filesystem( const char *path, const char *fs )
 	{
 		ok = true;
 	}
-#elif defined(__FreeBSD__)
+#else
 	if ( !strncmp( filesystem.f_fstypename, fs, strlen( fs ) ) )
 	{
 		ok = true;
 	}
-#elif defined(__solaris__) || defined(USE_SOLARIS)
-	if ( (uint)filesystem.f_basetype == 0xFF534D42 && !strncmp( fs, "cifs", strlen( fs )+1 ) )
-	{
-		ok = true;
-	}
-	else if ( (uint)filesystem.f_basetype == 0x517B && !strncmp( fs, "smbfs", strlen( fs )+1 ) )
-	{
-		ok = true;
-	}
-#elif defined(__irix__)
-	if ( (uint)filesystem.f_fstyp == 0xFF534D42 && !strncmp( fs, "cifs", strlen( fs )+1 ) )
-	{
-		ok = true;
-	}
-	else if ( (uint)filesystem.f_basetype == 0x517B && !strncmp( fs, "smbfs", strlen( fs )+1 ) )
-	{
-		ok = true;
-	}
 #endif
 	else
 	{
@@ -412,7 +381,10 @@ int main( int argc, char *argv[], char *envp[] )
 		{
 			if ( !find_program( "umount.cifs", path ) )
 			{
+			  if ( !find_program( "umount", path ) )
+			  {
 				exit( EXIT_FAILURE );
+			  }
 			}
 		}
 
